import { Directive, Renderer2, ElementRef, Input, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxOverflowShadowDirective {
    /**
     * @param {?} renderer
     * @param {?} elementRef
     */
    constructor(renderer, elementRef) {
        this.renderer = renderer;
        this.elementRef = elementRef;
        this.defaultBottomShadow = 'os_default-bottom-shadow';
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        const { nativeElement } = this.elementRef;
        this.observer = new IntersectionObserver(this.callback.bind(this), { root: nativeElement });
        this.createBottomPlaceholderDiv(nativeElement);
        this.createBottomShadowDiv(nativeElement);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.observer.disconnect();
    }
    /**
     * @private
     * @param {?} nativeElement
     * @return {?}
     */
    createBottomPlaceholderDiv(nativeElement) {
        /** @type {?} */
        const bottomPlaceholderDiv = this.renderer.createElement('div');
        this.renderer.appendChild(nativeElement, bottomPlaceholderDiv);
        this.observer.observe(bottomPlaceholderDiv);
    }
    /**
     * @private
     * @param {?} nativeElement
     * @return {?}
     */
    createBottomShadowDiv(nativeElement) {
        this.bottomShadowDiv = this.renderer.createElement('div');
        this.renderer.appendChild(nativeElement, this.bottomShadowDiv);
    }
    /**
     * @private
     * @param {?} entries
     * @return {?}
     */
    callback(entries) {
        const { isIntersecting } = entries[0];
        if (isIntersecting) {
            this.renderer.removeClass(this.bottomShadowDiv, this.defaultBottomShadow);
        }
        else {
            this.renderer.addClass(this.bottomShadowDiv, this.defaultBottomShadow);
        }
    }
}
NgxOverflowShadowDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngxOverflowShadow]'
            },] }
];
/** @nocollapse */
NgxOverflowShadowDirective.ctorParameters = () => [
    { type: Renderer2 },
    { type: ElementRef }
];
NgxOverflowShadowDirective.propDecorators = {
    defaultBottomShadow: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxOverflowShadowModule {
}
NgxOverflowShadowModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgxOverflowShadowDirective],
                imports: [],
                exports: [NgxOverflowShadowDirective]
            },] }
];

export { NgxOverflowShadowDirective, NgxOverflowShadowModule };
//# sourceMappingURL=ngx-overflow-shadow.js.map
